# Generated by Django 3.2.15 on 2022-09-29 17:20

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('integrated_channel', '0020_auto_20220929_1712'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='contentmetadataitemtransmission',
            name='api_response_body',
        ),
    ]
