# Generated by Django 3.2.20 on 2023-08-22 11:48

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import model_utils.fields
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0179_restore_historical_table'),
    ]

    operations = [
        migrations.CreateModel(
            name='ChatGPTResponse',
            fields=[
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('uuid', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('prompt', models.TextField(help_text='ChatGPT prompt.')),
                ('prompt_hash', models.CharField(editable=False, max_length=32)),
                ('response', models.TextField(help_text='ChatGPT response.')),
                ('enterprise_customer', models.ForeignKey(help_text='The enterprise that can be linked using this key.', on_delete=django.db.models.deletion.CASCADE, related_name='chat_gpt_prompts', to='enterprise.enterprisecustomer')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
