# Generated by Django 2.2.24 on 2021-10-13 10:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0144_auto_20211011_1030'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomer',
            name='hide_labor_market_data',
            field=models.BooleanField(default=False, help_text='Specifies whether the labor market data should be made known to the learner in learner portal.'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='hide_labor_market_data',
            field=models.BooleanField(default=False, help_text='Specifies whether the labor market data should be made known to the learner in learner portal.'),
        ),
    ]
