# Generated by Django 3.2.23 on 2024-04-08 11:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0204_auto_20240408_0723'),
    ]

    operations = [
        migrations.AlterField(
            model_name='enterprisecustomer',
            name='default_language',
            field=models.CharField(blank=True, choices=[('en', 'English'), ('es-419', 'Español (Latinoamérica)'), ('ar', 'العربية'), ('zh-cn', '中文 (简体)'), ('fr-ca', 'français (Canada)'), ('da', 'dansk'), ('de-de', 'Deutsch (Deutschland)'), ('el', 'Ελληνικά'), ('he', 'עברית'), ('hi', 'हिन्दी'), ('id', 'Bahasa Indonesia'), ('it-it', 'Italiano (Italia)'), ('pt-br', 'Português (Brasil)'), ('pt-pt', 'Português (Portugal)'), ('ru', 'Русский'), ('es-es', 'Español (España)'), ('sw', 'Kiswahili'), ('te', 'తెలుగు'), ('th', 'ไทย'), ('tr-tr', 'Türkçe (Türkiye)'), ('uk', 'українська')], default=None, help_text='Specifies the default language for learners of the organization.', max_length=25, null=True, verbose_name='Learner default language'),
        ),
        migrations.AlterField(
            model_name='historicalenterprisecustomer',
            name='default_language',
            field=models.CharField(blank=True, choices=[('en', 'English'), ('es-419', 'Español (Latinoamérica)'), ('ar', 'العربية'), ('zh-cn', '中文 (简体)'), ('fr-ca', 'français (Canada)'), ('da', 'dansk'), ('de-de', 'Deutsch (Deutschland)'), ('el', 'Ελληνικά'), ('he', 'עברית'), ('hi', 'हिन्दी'), ('id', 'Bahasa Indonesia'), ('it-it', 'Italiano (Italia)'), ('pt-br', 'Português (Brasil)'), ('pt-pt', 'Português (Portugal)'), ('ru', 'Русский'), ('es-es', 'Español (España)'), ('sw', 'Kiswahili'), ('te', 'తెలుగు'), ('th', 'ไทย'), ('tr-tr', 'Türkçe (Türkiye)'), ('uk', 'українська')], default=None, help_text='Specifies the default language for learners of the organization.', max_length=25, null=True, verbose_name='Learner default language'),
        ),
    ]
